==> 1.4.0.zip: 1.4.0/mysql(v_1.4.0).php <==
<?
/************************************************************
copyrigth Claudio Cardinale 2004-2012 tutti i diritti riservati
contatti: 	cardi@thecsea.it(o http://www.thecsea.it)
versione :	1.4.0
data:		15/12/2012 02:21

per scaricare l'ultima versione andare
su http://www.thecsea.it/progetti/classi_db
non eliminare il copyright e ridistribuire
sempre il codice accompagnato dalla licenza GNU
****************************************************************/
//classe con metodi di acceso al db, passare come parametri $db_host,$db_user,$db_password,$db_name
class Mysql{ 
	//proprietà private
	private $db_host = "";
	private $db_user = "";
	private $db_password = "";
	private $db_name = "";
	
	//proprietà pubbliche
	public $db = "";
	public $debug = false;

	public function __construct($db_host = "", $db_user = "", $db_password = "", $db_name = "") {
		//assgnazione proprietà
		//controllo che i parametro della funzione non siano nulli
		if ($db_host != "")
			$this->db_host = $db_host;

		if ($db_user != "")
			$this->db_user = $db_user;

		if ($db_password != "")
			$this->db_password = $db_password;

		if ($db_name != "")
			$this->db_name = $db_name;
		
		//mi conetto al db
		$this->db = @mysql_connect($db_host, $db_user, $db_password) or die ("Connessione al database non riuscita");
		@mysql_select_db($db_name, $this->db) or die ("Selezione del database non riuscita");
	}
	
	//metodi privati
	
	//ritorna la stringa sostituendo all'interno degli apici il carattere "," con \virgola e "'" con \apice
	private function metti_escape_virgola($stringa){
		$stringa = str_replace("\\","\\/",$stringa);
		$stringa = str_replace("\\/'","\\apice",$stringa);

		//eventualmente considerare divisori anche i doppi apici
		$len =  strlen($stringa);
		$apice = false;
		$str = "";
		for($i=0; $i<$len; $i++)
			if($stringa[$i] == "'"){
				if($apice)
					$apice = false;
				else
					$apice = true;
				$str .= $stringa[$i];
			}else if($stringa[$i] == ",")
				if($apice)
					$str .= "\\virgola";
				else
					$str .= $stringa[$i];
			else
					$str .= $stringa[$i];
		
		return $str;
	}
	
	//toglie gli escape per la virgola e gli apici
	private function togli_escape_virgola($stringa){
		$stringa = str_replace("\\virgola",",",$stringa);
		$stringa = str_replace("\\apice","\\/'",$stringa);
		return str_replace("\\/","\\",$stringa);
	}
	
	//unisce le diverse insert omogenne di un array
	private function insert_da_array($array,$newline=false){
		return ("(".implode("),".($newline?"\n":"")."(",(array)$array).")");
	}
	
	//metodi pubblici
	
	//esegue una guery
	public function esegui($query,$return=true){
		if($this->debug)
			print $query."<br />\n";
		$results = mysql_query($query, $this->db);
		if (!$results){
			if($this->debug)
				print "ERR";
			return false;
		}else
			if($return===true)
				return $results;
			else
				return true;
	}
	
	//inserisce un record nel database, in caso di righe multiple inserirle normalmente ma tramite un array, esmepio: array("'elemento11','elemento12'","'elemento21','elemento22'")
	public function inserisci ($campo, $valore, $table){
		if (($this->esegui("INSERT INTO `$table` ($campo) VALUES ".$this->insert_da_array($valore).";",false))===true)
			return true;
		else
			return false;
	}
	
	//ritorna il primo valore incrontrato nel database con una determinata condizione
	public function leggi ($valore_ritornato,$condizione,$table){
		$result = $this->esegui("SELECT $valore_ritornato FROM `$table` WHERE $condizione;");
		if($result !== false && ($row = mysql_fetch_array($result))!==false){
			mysql_free_result($result);
			return $row[$valore_ritornato];
		}
		return false;
	}

	//aggiorna un valore nel database
	public function aggiorna ($campo, $valore, $table, $condizione){
		//divisione dei parametri da aggiornare
		$valore = $this->metti_escape_virgola($valore);
		$campo = explode(",",$campo);
		$valore = explode(",",$valore);
		$len = count($campo);
		$set = "";
		for($i=0;$i<$len;$i++){
			$set .= $campo[$i]."=".$this->togli_escape_virgola($valore[$i]);
			if($i<($len-1))
				$set .= ",";
		}
		
		//agiornamento
		if ($results=$this->esegui("UPDATE `$table` SET $set WHERE $condizione;",false)===true)
			return true;
		return false;
	}
	
	//ritorna un elenco di valori incrontrati nel database con una determinata condizione, s ass= true e mat = false, ritorna solo la prima riga
	public function elenca ($campo_ritornato,$condizione,$ordine,$tipo_ordine,$table,$mat=false,$ass=false){
		$result = $this->esegui("SELECT $campo_ritornato FROM `$table` WHERE $condizione ORDER BY $ordine $tipo_ordine;");
		$i = 0;
		$rit = false;
		if($result!==false)
			//non associativo
			if($ass==false)
				while ($row = mysql_fetch_array($result))
					//matrice
					if($mat){
						for ($j =0; $j<count($row)/2;$j++ )
							$rit[$i][$j]=$row[$j];
						$i++;
					}
					//no matrice
					else
						for ($j =0; $j<count($row)/2;$j++ )
							$rit[$i++]=$row[$j];
			//associativo
			else
				while ($row = mysql_fetch_array($result)){
					$j = 0;
					//matrice
					if($mat){
						foreach($row as $key=>$value)
							if($j++%2)
								 $rit[$i][$key] = $value;	
						$i++;
					}
					//no matrice
					else{
						foreach($row as $key=>$value)
							if($j++%2)
								 $rit[$key] = $value;
						break;
					}
				}
		
		//libero la memoria
		if($rit!==false)
			mysql_free_result($result);
		
		//return
		return $rit;
	}
	
	//elimina una serie di valori dal database con una determinata condizione
	public function elimina ($condizione,$table){
		if (($this->esegui("DELETE FROM `$table` WHERE $condizione;",false))===true&&mysql_affected_rows())
			return true;
		else
			return false;
			
	}
	
	//elimina una tabella dal databse
	public function elimina_tabella ($table){
		if (($this->esegui("DROP TABLE `$table`;",false))===true)
			return true;
		else
			return false;
	}
	
	//ritorna le info di una tabella
	public function info ($valore_ritornato,$table){
		$result = $this->esegui("show table status like '$table';");
		if($result !== false && ($row = mysql_fetch_array($result))!==false)
			return isset($row[$valore_ritornato])?$row[$valore_ritornato]:false;
		return false;
	}
	
	//backup di una tabella
	public function backup_tabella($table){
		//inizializzazioni
		$ret = "";
		$campi = array();
		$valori = array();
		$valori2 = array();
		
		//create table
		$result = $this->esegui("SHOW CREATE TABLE `$table`;");
		if($result !== false && ($row = mysql_fetch_array($result))!==false && isset($row['Create Table']))
			$ret .= $row['Create Table'].";";
		else
			return false;
		
		//select
		if(($valori = $this->elenca("*","1","id","asc",$table,true,true))===false)
			return $ret;
		
		//campi
		foreach($valori[0] as $key=>$value)
			$campi[] = $key;
		$campi = "`".implode("`,`",$campi)."`";
		
		//valori
		foreach($valori as $value)
			$valori2[] = "'".implode("','",$value)."'";
		
		//insert
		$ret .= "\nINSERT INTO `$table` ($campi) VALUES ".$this->insert_da_array($valori2,true).";\n";
		
		//return
		return $ret;
	}
}
?>

==> 1.5.0.zip: 1.5.0/mysql(v_1.5.0).php <==
<?
/************************************************************
copyrigth Claudio Cardinale 2004-2013 tutti i diritti riservati
contatti: 	cardi@thecsea.it(o http://www.thecsea.it)
versione :	1.5.0
data:		11/04/2013 20:49

per scaricare l'ultima versione andare
su http://www.thecsea.it/progetti/classi_db
non eliminare il copyright e ridistribuire
sempre il codice accompagnato dalla licenza GNU
****************************************************************/
//classe con metodi di acceso al db, passare come parametri $db_host,$db_user,$db_password,$db_name
class Mysql{ 
	//proprietà private
	private $db_host = "";
	private $db_user = "";
	private $db_password = "";
	private $db_name = "";
	
	//proprietà pubbliche
	public $db = "";
	public $debug = false;

	public function __construct($db_host = "", $db_user = "", $db_password = "", $db_name = "") {
		//assgnazione proprietà
		//controllo che i parametro della funzione non siano nulli
		if ($db_host != "")
			$this->db_host = $db_host;

		if ($db_user != "")
			$this->db_user = $db_user;

		if ($db_password != "")
			$this->db_password = $db_password;

		if ($db_name != "")
			$this->db_name = $db_name;
		
		//mi conetto al db
		$this->db = @mysql_connect($db_host, $db_user, $db_password) or die ("Connessione al database non riuscita");
		@mysql_select_db($db_name, $this->db) or die ("Selezione del database non riuscita");
	}
	
	//metodi privati
	
	//ritorna la stringa sostituendo all'interno degli apici il carattere "," con \virgola e "'" con \apice
	private function metti_escape_virgola($stringa){
		$stringa = str_replace("\\","\\/",$stringa);
		$stringa = str_replace("\\/'","\\apice",$stringa);

		//eventualmente considerare divisori anche i doppi apici
		$len =  strlen($stringa);
		$apice = false;
		$str = "";
		for($i=0; $i<$len; $i++)
			if($stringa[$i] == "'"){
				if($apice)
					$apice = false;
				else
					$apice = true;
				$str .= $stringa[$i];
			}else if($stringa[$i] == ",")
				if($apice)
					$str .= "\\virgola";
				else
					$str .= $stringa[$i];
			else
					$str .= $stringa[$i];
		
		return $str;
	}
	
	//toglie gli escape per la virgola e gli apici
	private function togli_escape_virgola($stringa){
		$stringa = str_replace("\\virgola",",",$stringa);
		$stringa = str_replace("\\apice","\\/'",$stringa);
		return str_replace("\\/","\\",$stringa);
	}
	
	//unisce le diverse insert omogenne di un array
	private function insert_da_array($array,$newline=false){
		return ("(".implode("),".($newline?"\n":"")."(",(array)$array).")");
	}
	
	//metodi pubblici
	
	//esegue una guery
	public function esegui($query,$return=true){
		if($this->debug)
			print $query."<br />\n";
		$results = mysql_query($query, $this->db);
		if (!$results){
			if($this->debug)
				print "ERR";
			return false;
		}else
			if($return===true)
				return $results;
			else
				return true;
	}
	
	//inserisce un record nel database, in caso di righe multiple inserirle normalmente ma tramite un array, esmepio: array("'elemento11','elemento12'","'elemento21','elemento22'")
	public function inserisci ($campo, $valore, $table){
		if (($this->esegui("INSERT INTO `$table` ($campo) VALUES ".$this->insert_da_array($valore).";",false))===true)
			return true;
		else
			return false;
	}
	
	//ritorna il primo valore incrontrato nel database con una determinata condizione
	public function leggi ($valore_ritornato,$condizione,$table){
		$result = $this->esegui("SELECT $valore_ritornato FROM `$table` WHERE $condizione;");
		if($result !== false && ($row = mysql_fetch_array($result))!==false){
			mysql_free_result($result);
			return $row[$valore_ritornato];
		}
		return false;
	}

	//aggiorna un valore nel database
	public function aggiorna ($campo, $valore, $table, $condizione){
		//divisione dei parametri da aggiornare
		$valore = $this->metti_escape_virgola($valore);
		$campo = explode(",",$campo);
		$valore = explode(",",$valore);
		$len = count($campo);
		$set = "";
		for($i=0;$i<$len;$i++){
			$set .= $campo[$i]."=".$this->togli_escape_virgola($valore[$i]);
			if($i<($len-1))
				$set .= ",";
		}
		
		//agiornamento
		if ($results=$this->esegui("UPDATE `$table` SET $set WHERE $condizione;",false)===true)
			return true;
		return false;
	}
	
	//ritorna un elenco di valori incrontrati nel database con una determinata condizione, s ass= true e mat = false, ritorna solo la prima riga
	public function elenca ($campo_ritornato,$condizione,$ordine,$tipo_ordine,$table,$mat=false,$ass=false){
		$result = $this->esegui("SELECT $campo_ritornato FROM `$table` WHERE $condizione ORDER BY $ordine $tipo_ordine;");
		$i = 0;
		$rit = false;
		if($result!==false)
			//non associativo
			if($ass==false)
				while ($row = mysql_fetch_array($result))
					//matrice
					if($mat){
						for ($j =0; $j<count($row)/2;$j++ )
							$rit[$i][$j]=$row[$j];
						$i++;
					}
					//no matrice
					else
						for ($j =0; $j<count($row)/2;$j++ )
							$rit[$i++]=$row[$j];
			//associativo
			else
				while ($row = mysql_fetch_array($result)){
					$j = 0;
					//matrice
					if($mat){
						foreach($row as $key=>$value)
							if($j++%2)
								 $rit[$i][$key] = $value;	
						$i++;
					}
					//no matrice
					else{
						foreach($row as $key=>$value)
							if($j++%2)
								 $rit[$key] = $value;
						break;
					}
				}
		
		//libero la memoria
		if($rit!==false)
			mysql_free_result($result);
		
		//return
		return $rit;
	}
	
	//elimina una serie di valori dal database con una determinata condizione
	public function elimina ($condizione,$table){
		if (($this->esegui("DELETE FROM `$table` WHERE $condizione;",false))===true&&mysql_affected_rows())
			return true;
		else
			return false;
			
	}
	
	//elimina una tabella dal databse
	public function elimina_tabella ($table){
		if (($this->esegui("DROP TABLE `$table`;",false))===true)
			return true;
		else
			return false;
	}
	
	//ritorna le info di una tabella
	public function info ($valore_ritornato,$table){
		$result = $this->esegui("show table status like '$table';");
		if($result !== false && ($row = mysql_fetch_array($result))!==false)
			return isset($row[$valore_ritornato])?$row[$valore_ritornato]:false;
		return false;
	}
	
	//ritorna l'elenco delle tabelle del database selezionato nel costruttore
	public function elenca_tabelle(){
		$result = $this->esegui("SHOW TABLES;");
		$ret = false;
		
		//inserisco i risultati in un array
		if($result!==false){
			$i=0;
			while ($row = mysql_fetch_array($result))
				$ret[$i++]=$row[0];
		}
		
		//libero la memoria
		if($ret!==false)
			mysql_free_result($result);
		
		//return
		return $ret;
	}
	
	//ritorna l'elenco dei databases
	public function elenca_databases(){
		$result = $this->esegui("SHOW DATABASES;");
		$ret = false;
		
		//inserisco i risultati in un array
		if($result!==false){
			$i=0;
			while ($row = mysql_fetch_array($result))
				$ret[$i++]=$row[0];
		}
		
		//libero la memoria
		if($ret!==false)
			mysql_free_result($result);
		
		//return
		return $ret;
	}
	
	//backup di una tabella
	public function backup_tabella($table){
		//inizializzazioni
		$ret = "";
		$campi = array();
		$valori = array();
		$valori2 = array();
		
		//create table
		$result = $this->esegui("SHOW CREATE TABLE `$table`;");
		if($result !== false && ($row = mysql_fetch_array($result))!==false && isset($row['Create Table']))
			$ret .= $row['Create Table'].";";
		else
			return false;
		
		//select
		if(($valori = $this->elenca("*","1","id","asc",$table,true,true))===false)
			return $ret;
		
		//campi
		foreach($valori[0] as $key=>$value)
			$campi[] = $key;
		$campi = "`".implode("`,`",$campi)."`";
		
		//valori
		foreach($valori as $value)
			$valori2[] = "'".implode("','",$value)."'";
		
		//insert
		$ret .= "\nINSERT INTO `$table` ($campi) VALUES ".$this->insert_da_array($valori2,true).";\n";
		
		//libero la memoria
		if($ret!==false)
			mysql_free_result($result);

		
		//return
		return $ret;
	}
}
?>
